@@ -29,7 +29,11 @@ class Method(Subscriber):
             result = self.callback(json.loads(body))
             channel.basic_publish(exchange='',
                 routing_key=header.reply_to,
-                properties=pika.BasicProperties(correlation_id=header.correlation_id),
+                properties=pika.BasicProperties(
+                    correlation_id=header.correlation_id,
+                    content_type='application/json',
+                    content_encoding='utf-8',
+                ),
                 body=json.dumps(result))
             channel.basic_ack(delivery_tag=method.delivery_tag)
         except Exception:
@@ -97,4 +101,3 @@ class Amqp(object):
 
         except:
             logger.exception('AMQP open channel error')
-
